# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ChallengeSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'challenge_type': 'str',
        'challenge_types': 'list[str]',
        'user_id': 'str',
        'send_now': 'bool',
        'timeout_seconds': 'int',
        'response_uri': 'str',
        'origin': 'str',
        'challenge_endpoints': 'list[ChallengeEndpoint]'
    }

    attribute_map = {
        'challenge_type': 'challenge_type',
        'challenge_types': 'challenge_types',
        'user_id': 'user_id',
        'send_now': 'send_now',
        'timeout_seconds': 'timeout_seconds',
        'response_uri': 'response_uri',
        'origin': 'origin',
        'challenge_endpoints': 'challenge_endpoints'
    }

    def __init__(self, challenge_type=None, challenge_types=None, user_id=None, send_now=False, timeout_seconds=600, response_uri=None, origin=None, challenge_endpoints=None, local_vars_configuration=None):  # noqa: E501
        """ChallengeSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._challenge_type = None
        self._challenge_types = None
        self._user_id = None
        self._send_now = None
        self._timeout_seconds = None
        self._response_uri = None
        self._origin = None
        self._challenge_endpoints = None
        self.discriminator = None

        if challenge_type is not None:
            self.challenge_type = challenge_type
        if challenge_types is not None:
            self.challenge_types = challenge_types
        self.user_id = user_id
        if send_now is not None:
            self.send_now = send_now
        if timeout_seconds is not None:
            self.timeout_seconds = timeout_seconds
        if response_uri is not None:
            self.response_uri = response_uri
        if origin is not None:
            self.origin = origin
        if challenge_endpoints is not None:
            self.challenge_endpoints = challenge_endpoints

    @property
    def challenge_type(self):
        """Gets the challenge_type of this ChallengeSpec.  # noqa: E501

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :return: The challenge_type of this ChallengeSpec.  # noqa: E501
        :rtype: str
        """
        return self._challenge_type

    @challenge_type.setter
    def challenge_type(self, challenge_type):
        """Sets the challenge_type of this ChallengeSpec.

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :param challenge_type: The challenge_type of this ChallengeSpec.  # noqa: E501
        :type: str
        """

        self._challenge_type = challenge_type

    @property
    def challenge_types(self):
        """Gets the challenge_types of this ChallengeSpec.  # noqa: E501

        List of acceptable challenge types for this challenge request. The subsequent challenge answer must be one of these types.  # noqa: E501

        :return: The challenge_types of this ChallengeSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._challenge_types

    @challenge_types.setter
    def challenge_types(self, challenge_types):
        """Sets the challenge_types of this ChallengeSpec.

        List of acceptable challenge types for this challenge request. The subsequent challenge answer must be one of these types.  # noqa: E501

        :param challenge_types: The challenge_types of this ChallengeSpec.  # noqa: E501
        :type: list[str]
        """

        self._challenge_types = challenge_types

    @property
    def user_id(self):
        """Gets the user_id of this ChallengeSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The user_id of this ChallengeSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ChallengeSpec.

        Unique identifier  # noqa: E501

        :param user_id: The user_id of this ChallengeSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def send_now(self):
        """Gets the send_now of this ChallengeSpec.  # noqa: E501

        Whether to send the challenge now. If the challenge hasn't yet been set, setting this to true will send the challenge. If the challenge has been sent, changing this has no effect.   # noqa: E501

        :return: The send_now of this ChallengeSpec.  # noqa: E501
        :rtype: bool
        """
        return self._send_now

    @send_now.setter
    def send_now(self, send_now):
        """Sets the send_now of this ChallengeSpec.

        Whether to send the challenge now. If the challenge hasn't yet been set, setting this to true will send the challenge. If the challenge has been sent, changing this has no effect.   # noqa: E501

        :param send_now: The send_now of this ChallengeSpec.  # noqa: E501
        :type: bool
        """

        self._send_now = send_now

    @property
    def timeout_seconds(self):
        """Gets the timeout_seconds of this ChallengeSpec.  # noqa: E501

        For how long the system will accept answers for the challenge. After this time, if the challenge is not in the `challenge_passed` state, it will transition into the `timed_out` state.   # noqa: E501

        :return: The timeout_seconds of this ChallengeSpec.  # noqa: E501
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """Sets the timeout_seconds of this ChallengeSpec.

        For how long the system will accept answers for the challenge. After this time, if the challenge is not in the `challenge_passed` state, it will transition into the `timed_out` state.   # noqa: E501

        :param timeout_seconds: The timeout_seconds of this ChallengeSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                timeout_seconds is not None and timeout_seconds > 3600):  # noqa: E501
            raise ValueError("Invalid value for `timeout_seconds`, must be a value less than or equal to `3600`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                timeout_seconds is not None and timeout_seconds < 1):  # noqa: E501
            raise ValueError("Invalid value for `timeout_seconds`, must be a value greater than or equal to `1`")  # noqa: E501

        self._timeout_seconds = timeout_seconds

    @property
    def response_uri(self):
        """Gets the response_uri of this ChallengeSpec.  # noqa: E501

        The base URI which the user should retrieve in order to answer the challenge. It is expected that this will be an HTTP endpoint serving `text/html` content. The final URI that the user should retrieve will be this value, extended with three form parameters that may be used to invoke the `answer` endpoint.   - challenge_answer: A string which is the answer code.   - challenge_uid: the id of the user being challenged.   - challenge_id: the id of the challenge. In the example, this would turn into something like: `https://auth.egov.city/mfa-answer?challenge_answer=supersecret&challenge_uid=1234&challenge_id=5678`   # noqa: E501

        :return: The response_uri of this ChallengeSpec.  # noqa: E501
        :rtype: str
        """
        return self._response_uri

    @response_uri.setter
    def response_uri(self, response_uri):
        """Sets the response_uri of this ChallengeSpec.

        The base URI which the user should retrieve in order to answer the challenge. It is expected that this will be an HTTP endpoint serving `text/html` content. The final URI that the user should retrieve will be this value, extended with three form parameters that may be used to invoke the `answer` endpoint.   - challenge_answer: A string which is the answer code.   - challenge_uid: the id of the user being challenged.   - challenge_id: the id of the challenge. In the example, this would turn into something like: `https://auth.egov.city/mfa-answer?challenge_answer=supersecret&challenge_uid=1234&challenge_id=5678`   # noqa: E501

        :param response_uri: The response_uri of this ChallengeSpec.  # noqa: E501
        :type: str
        """

        self._response_uri = response_uri

    @property
    def origin(self):
        """Gets the origin of this ChallengeSpec.  # noqa: E501

        The origin that is initiating the challenge.  # noqa: E501

        :return: The origin of this ChallengeSpec.  # noqa: E501
        :rtype: str
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """Sets the origin of this ChallengeSpec.

        The origin that is initiating the challenge.  # noqa: E501

        :param origin: The origin of this ChallengeSpec.  # noqa: E501
        :type: str
        """

        self._origin = origin

    @property
    def challenge_endpoints(self):
        """Gets the challenge_endpoints of this ChallengeSpec.  # noqa: E501

        List of endpoint ids to challenge for this challenge request. At least one entry is required here when the challenge type includes webauthn.  # noqa: E501

        :return: The challenge_endpoints of this ChallengeSpec.  # noqa: E501
        :rtype: list[ChallengeEndpoint]
        """
        return self._challenge_endpoints

    @challenge_endpoints.setter
    def challenge_endpoints(self, challenge_endpoints):
        """Sets the challenge_endpoints of this ChallengeSpec.

        List of endpoint ids to challenge for this challenge request. At least one entry is required here when the challenge type includes webauthn.  # noqa: E501

        :param challenge_endpoints: The challenge_endpoints of this ChallengeSpec.  # noqa: E501
        :type: list[ChallengeEndpoint]
        """

        self._challenge_endpoints = challenge_endpoints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChallengeSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChallengeSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UserApplicationAccessInfoStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'org_name': 'str',
        'parent_org_id': 'str',
        'parent_org_name': 'str',
        'application_name': 'str',
        'application_url': 'str',
        'application_description': 'str',
        'application_category': 'str',
        'icon_url': 'str',
        'access_level': 'str',
        'application_default_role_name': 'str',
        'application_default_role_id': 'str',
        'roles': 'list[str]'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'org_name': 'org_name',
        'parent_org_id': 'parent_org_id',
        'parent_org_name': 'parent_org_name',
        'application_name': 'application_name',
        'application_url': 'application_url',
        'application_description': 'application_description',
        'application_category': 'application_category',
        'icon_url': 'icon_url',
        'access_level': 'access_level',
        'application_default_role_name': 'application_default_role_name',
        'application_default_role_id': 'application_default_role_id',
        'roles': 'roles'
    }

    def __init__(self, user_id=None, org_id=None, org_name=None, parent_org_id=None, parent_org_name=None, application_name=None, application_url=None, application_description=None, application_category=None, icon_url='https://storage.googleapis.com/agilicus/logo.svg', access_level=None, application_default_role_name=None, application_default_role_id=None, roles=None, local_vars_configuration=None):  # noqa: E501
        """UserApplicationAccessInfoStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._org_name = None
        self._parent_org_id = None
        self._parent_org_name = None
        self._application_name = None
        self._application_url = None
        self._application_description = None
        self._application_category = None
        self._icon_url = None
        self._access_level = None
        self._application_default_role_name = None
        self._application_default_role_id = None
        self._roles = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        self.org_name = org_name
        if parent_org_id is not None:
            self.parent_org_id = parent_org_id
        if parent_org_name is not None:
            self.parent_org_name = parent_org_name
        self.application_name = application_name
        self.application_url = application_url
        if application_description is not None:
            self.application_description = application_description
        if application_category is not None:
            self.application_category = application_category
        if icon_url is not None:
            self.icon_url = icon_url
        self.access_level = access_level
        self.application_default_role_name = application_default_role_name
        self.application_default_role_id = application_default_role_id
        if roles is not None:
            self.roles = roles

    @property
    def user_id(self):
        """Gets the user_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the User to which this record applies.   # noqa: E501

        :return: The user_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserApplicationAccessInfoStatus.

        The unique id of the User to which this record applies.   # noqa: E501

        :param user_id: The user_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) > 40):
            raise ValueError("Invalid value for `user_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) < 1):
            raise ValueError("Invalid value for `user_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :return: The org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this UserApplicationAccessInfoStatus.

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :param org_id: The org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def org_name(self):
        """Gets the org_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of Organisation to which this record applies.   # noqa: E501

        :return: The org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this UserApplicationAccessInfoStatus.

        The name of Organisation to which this record applies.   # noqa: E501

        :param org_name: The org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_name is None:  # noqa: E501
            raise ValueError("Invalid value for `org_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_name is not None and len(org_name) > 100):
            raise ValueError("Invalid value for `org_name`, length must be less than or equal to `100`")  # noqa: E501

        self._org_name = org_name

    @property
    def parent_org_id(self):
        """Gets the parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :return: The parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._parent_org_id

    @parent_org_id.setter
    def parent_org_id(self, parent_org_id):
        """Sets the parent_org_id of this UserApplicationAccessInfoStatus.

        The unique id of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :param parent_org_id: The parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                parent_org_id is not None and len(parent_org_id) > 40):
            raise ValueError("Invalid value for `parent_org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                parent_org_id is not None and len(parent_org_id) < 1):
            raise ValueError("Invalid value for `parent_org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._parent_org_id = parent_org_id

    @property
    def parent_org_name(self):
        """Gets the parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :return: The parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._parent_org_name

    @parent_org_name.setter
    def parent_org_name(self, parent_org_name):
        """Sets the parent_org_name of this UserApplicationAccessInfoStatus.

        The name of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :param parent_org_name: The parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                parent_org_name is not None and len(parent_org_name) > 100):
            raise ValueError("Invalid value for `parent_org_name`, length must be less than or equal to `100`")  # noqa: E501

        self._parent_org_name = parent_org_name

    @property
    def application_name(self):
        """Gets the application_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the application.   # noqa: E501

        :return: The application_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """Sets the application_name of this UserApplicationAccessInfoStatus.

        The name of the application.   # noqa: E501

        :param application_name: The application_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_name is None:  # noqa: E501
            raise ValueError("Invalid value for `application_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_name is not None and len(application_name) > 128):
            raise ValueError("Invalid value for `application_name`, length must be less than or equal to `128`")  # noqa: E501

        self._application_name = application_name

    @property
    def application_url(self):
        """Gets the application_url of this UserApplicationAccessInfoStatus.  # noqa: E501

        The url of the application   # noqa: E501

        :return: The application_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_url

    @application_url.setter
    def application_url(self, application_url):
        """Sets the application_url of this UserApplicationAccessInfoStatus.

        The url of the application   # noqa: E501

        :param application_url: The application_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_url is None:  # noqa: E501
            raise ValueError("Invalid value for `application_url`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_url is not None and len(application_url) > 1024):
            raise ValueError("Invalid value for `application_url`, length must be less than or equal to `1024`")  # noqa: E501

        self._application_url = application_url

    @property
    def application_description(self):
        """Gets the application_description of this UserApplicationAccessInfoStatus.  # noqa: E501

        The description of the application   # noqa: E501

        :return: The application_description of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_description

    @application_description.setter
    def application_description(self, application_description):
        """Sets the application_description of this UserApplicationAccessInfoStatus.

        The description of the application   # noqa: E501

        :param application_description: The application_description of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """

        self._application_description = application_description

    @property
    def application_category(self):
        """Gets the application_category of this UserApplicationAccessInfoStatus.  # noqa: E501

        A category used to group similar applications together   # noqa: E501

        :return: The application_category of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_category

    @application_category.setter
    def application_category(self, application_category):
        """Sets the application_category of this UserApplicationAccessInfoStatus.

        A category used to group similar applications together   # noqa: E501

        :param application_category: The application_category of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_category is not None and len(application_category) > 100):
            raise ValueError("Invalid value for `application_category`, length must be less than or equal to `100`")  # noqa: E501

        self._application_category = application_category

    @property
    def icon_url(self):
        """Gets the icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501

        A url pointing to an icon representing this application.   # noqa: E501

        :return: The icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this UserApplicationAccessInfoStatus.

        A url pointing to an icon representing this application.   # noqa: E501

        :param icon_url: The icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                icon_url is not None and len(icon_url) > 100):
            raise ValueError("Invalid value for `icon_url`, length must be less than or equal to `100`")  # noqa: E501

        self._icon_url = icon_url

    @property
    def access_level(self):
        """Gets the access_level of this UserApplicationAccessInfoStatus.  # noqa: E501

        Whether the user has access, has requested access, etc. The possible values have the following meanings:   - requested: the user has requested access to this instance.   - granted: the user has access to this instance.   - none: the user has no relation to this application.   # noqa: E501

        :return: The access_level of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this UserApplicationAccessInfoStatus.

        Whether the user has access, has requested access, etc. The possible values have the following meanings:   - requested: the user has requested access to this instance.   - granted: the user has access to this instance.   - none: the user has no relation to this application.   # noqa: E501

        :param access_level: The access_level of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and access_level is None:  # noqa: E501
            raise ValueError("Invalid value for `access_level`, must not be `None`")  # noqa: E501
        allowed_values = ["requested", "granted", "none"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and access_level not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(access_level, allowed_values)
            )

        self._access_level = access_level

    @property
    def application_default_role_name(self):
        """Gets the application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :return: The application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_default_role_name

    @application_default_role_name.setter
    def application_default_role_name(self, application_default_role_name):
        """Sets the application_default_role_name of this UserApplicationAccessInfoStatus.

        The name of the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :param application_default_role_name: The application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_name is not None and len(application_default_role_name) > 100):
            raise ValueError("Invalid value for `application_default_role_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_name is not None and len(application_default_role_name) < 1):
            raise ValueError("Invalid value for `application_default_role_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._application_default_role_name = application_default_role_name

    @property
    def application_default_role_id(self):
        """Gets the application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :return: The application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_default_role_id

    @application_default_role_id.setter
    def application_default_role_id(self, application_default_role_id):
        """Sets the application_default_role_id of this UserApplicationAccessInfoStatus.

        The unique id the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :param application_default_role_id: The application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_id is not None and len(application_default_role_id) > 40):
            raise ValueError("Invalid value for `application_default_role_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_id is not None and len(application_default_role_id) < 1):
            raise ValueError("Invalid value for `application_default_role_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._application_default_role_id = application_default_role_id

    @property
    def roles(self):
        """Gets the roles of this UserApplicationAccessInfoStatus.  # noqa: E501

        The list of roles held by the user for the given application  # noqa: E501

        :return: The roles of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this UserApplicationAccessInfoStatus.

        The list of roles held by the user for the given application  # noqa: E501

        :param roles: The roles of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserApplicationAccessInfoStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserApplicationAccessInfoStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.policy_spec import PolicySpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestPolicySpec(unittest.TestCase):
    """PolicySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PolicySpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.policy_spec.PolicySpec()  # noqa: E501
        if include_optional :
            return PolicySpec(
                name = 'Staging org authentication policy', 
                issuer_id = 'asdfg123hjkl', 
                org_id = 'asdfg123hjkl', 
                supported_mfa_methods = ["totp","webauthn"], 
                default_action = 'enroll', 
                rules = [
                    agilicus_api.models.policy_rule.PolicyRule(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.policy_rule_spec.PolicyRuleSpec(
                            name = 'blocked IPs rule', 
                            action = 'enroll', 
                            priority = 1, 
                            org_id = 'asdfg123hjkl', 
                            conditions = [
                                agilicus_api.models.policy_condition.PolicyCondition(
                                    condition_type = 'type_client_id_list', 
                                    inverted = True, 
                                    value = 'my-city-org', 
                                    operator = 'equals', 
                                    field = 'client.name', 
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    updated = '2015-07-07T15:49:51.230+02:00', )
                                ], ), )
                    ], 
                policy_groups = [
                    agilicus_api.models.policy_group.PolicyGroup(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.policy_group_spec.PolicyGroupSpec(
                            name = '0', 
                            rule_ids = [
                                '123'
                                ], ), )
                    ]
            )
        else :
            return PolicySpec(
                issuer_id = 'asdfg123hjkl',
                supported_mfa_methods = ["totp","webauthn"],
                default_action = 'enroll',
        )

    def testPolicySpec(self):
        """Test PolicySpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Environment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created': 'datetime',
        'name': 'str',
        'maintenance_org_id': 'str',
        'version_tag': 'str',
        'config_mount_path': 'str',
        'config_as_mount': 'str',
        'config_as_env': 'str',
        'secrets_mount_path': 'str',
        'secrets_as_mount': 'str',
        'secrets_as_env': 'str',
        'application_services': 'list[ApplicationService]',
        'serverless_image': 'str',
        'status': 'EnvironmentStatus',
        'updated': 'datetime'
    }

    attribute_map = {
        'created': 'created',
        'name': 'name',
        'maintenance_org_id': 'maintenance_org_id',
        'version_tag': 'version_tag',
        'config_mount_path': 'config_mount_path',
        'config_as_mount': 'config_as_mount',
        'config_as_env': 'config_as_env',
        'secrets_mount_path': 'secrets_mount_path',
        'secrets_as_mount': 'secrets_as_mount',
        'secrets_as_env': 'secrets_as_env',
        'application_services': 'application_services',
        'serverless_image': 'serverless_image',
        'status': 'status',
        'updated': 'updated'
    }

    def __init__(self, created=None, name=None, maintenance_org_id=None, version_tag=None, config_mount_path=None, config_as_mount=None, config_as_env=None, secrets_mount_path=None, secrets_as_mount=None, secrets_as_env=None, application_services=None, serverless_image=None, status=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """Environment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created = None
        self._name = None
        self._maintenance_org_id = None
        self._version_tag = None
        self._config_mount_path = None
        self._config_as_mount = None
        self._config_as_env = None
        self._secrets_mount_path = None
        self._secrets_as_mount = None
        self._secrets_as_env = None
        self._application_services = None
        self._serverless_image = None
        self._status = None
        self._updated = None
        self.discriminator = None

        if created is not None:
            self.created = created
        self.name = name
        if maintenance_org_id is not None:
            self.maintenance_org_id = maintenance_org_id
        if version_tag is not None:
            self.version_tag = version_tag
        if config_mount_path is not None:
            self.config_mount_path = config_mount_path
        if config_as_mount is not None:
            self.config_as_mount = config_as_mount
        if config_as_env is not None:
            self.config_as_env = config_as_env
        if secrets_mount_path is not None:
            self.secrets_mount_path = secrets_mount_path
        if secrets_as_mount is not None:
            self.secrets_as_mount = secrets_as_mount
        if secrets_as_env is not None:
            self.secrets_as_env = secrets_as_env
        if application_services is not None:
            self.application_services = application_services
        if serverless_image is not None:
            self.serverless_image = serverless_image
        if status is not None:
            self.status = status
        if updated is not None:
            self.updated = updated

    @property
    def created(self):
        """Gets the created of this Environment.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this Environment.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Environment.

        Creation time  # noqa: E501

        :param created: The created of this Environment.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def name(self):
        """Gets the name of this Environment.  # noqa: E501

        Environment name  # noqa: E501

        :return: The name of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Environment.

        Environment name  # noqa: E501

        :param name: The name of this Environment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 40):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def maintenance_org_id(self):
        """Gets the maintenance_org_id of this Environment.  # noqa: E501

        The Organisation which is responsibile for maintaining this Environment. Often this will be the same Organisation as the owning Application. However, sometimes it makes sense to delegate this responsibility to another Organisation. To do so, set this field to that Organisation's identifier. Users with sufficient permissions in that organisation will be able to modify this Environment. If the maintenance_org_id is not provided, it will populaed with that of the parent application's organisation.   # noqa: E501

        :return: The maintenance_org_id of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_org_id

    @maintenance_org_id.setter
    def maintenance_org_id(self, maintenance_org_id):
        """Sets the maintenance_org_id of this Environment.

        The Organisation which is responsibile for maintaining this Environment. Often this will be the same Organisation as the owning Application. However, sometimes it makes sense to delegate this responsibility to another Organisation. To do so, set this field to that Organisation's identifier. Users with sufficient permissions in that organisation will be able to modify this Environment. If the maintenance_org_id is not provided, it will populaed with that of the parent application's organisation.   # noqa: E501

        :param maintenance_org_id: The maintenance_org_id of this Environment.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                maintenance_org_id is not None and len(maintenance_org_id) > 40):
            raise ValueError("Invalid value for `maintenance_org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                maintenance_org_id is not None and len(maintenance_org_id) < 1):
            raise ValueError("Invalid value for `maintenance_org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._maintenance_org_id = maintenance_org_id

    @property
    def version_tag(self):
        """Gets the version_tag of this Environment.  # noqa: E501

        The version of the container to run. Required if the owning application is hosted.   # noqa: E501

        :return: The version_tag of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._version_tag

    @version_tag.setter
    def version_tag(self, version_tag):
        """Sets the version_tag of this Environment.

        The version of the container to run. Required if the owning application is hosted.   # noqa: E501

        :param version_tag: The version_tag of this Environment.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                version_tag is not None and len(version_tag) > 40):
            raise ValueError("Invalid value for `version_tag`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                version_tag is not None and len(version_tag) < 1):
            raise ValueError("Invalid value for `version_tag`, length must be greater than or equal to `1`")  # noqa: E501

        self._version_tag = version_tag

    @property
    def config_mount_path(self):
        """Gets the config_mount_path of this Environment.  # noqa: E501

        config_as_mount file path  # noqa: E501

        :return: The config_mount_path of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._config_mount_path

    @config_mount_path.setter
    def config_mount_path(self, config_mount_path):
        """Sets the config_mount_path of this Environment.

        config_as_mount file path  # noqa: E501

        :param config_mount_path: The config_mount_path of this Environment.  # noqa: E501
        :type: str
        """

        self._config_mount_path = config_mount_path

    @property
    def config_as_mount(self):
        """Gets the config_as_mount of this Environment.  # noqa: E501

        A json object of config applied as file mounted  # noqa: E501

        :return: The config_as_mount of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._config_as_mount

    @config_as_mount.setter
    def config_as_mount(self, config_as_mount):
        """Sets the config_as_mount of this Environment.

        A json object of config applied as file mounted  # noqa: E501

        :param config_as_mount: The config_as_mount of this Environment.  # noqa: E501
        :type: str
        """

        self._config_as_mount = config_as_mount

    @property
    def config_as_env(self):
        """Gets the config_as_env of this Environment.  # noqa: E501

        A json object of config applied as environment  # noqa: E501

        :return: The config_as_env of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._config_as_env

    @config_as_env.setter
    def config_as_env(self, config_as_env):
        """Sets the config_as_env of this Environment.

        A json object of config applied as environment  # noqa: E501

        :param config_as_env: The config_as_env of this Environment.  # noqa: E501
        :type: str
        """

        self._config_as_env = config_as_env

    @property
    def secrets_mount_path(self):
        """Gets the secrets_mount_path of this Environment.  # noqa: E501

        secret_as_mount file path  # noqa: E501

        :return: The secrets_mount_path of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._secrets_mount_path

    @secrets_mount_path.setter
    def secrets_mount_path(self, secrets_mount_path):
        """Sets the secrets_mount_path of this Environment.

        secret_as_mount file path  # noqa: E501

        :param secrets_mount_path: The secrets_mount_path of this Environment.  # noqa: E501
        :type: str
        """

        self._secrets_mount_path = secrets_mount_path

    @property
    def secrets_as_mount(self):
        """Gets the secrets_as_mount of this Environment.  # noqa: E501

        A json object of secrets applied as file mounted  # noqa: E501

        :return: The secrets_as_mount of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._secrets_as_mount

    @secrets_as_mount.setter
    def secrets_as_mount(self, secrets_as_mount):
        """Sets the secrets_as_mount of this Environment.

        A json object of secrets applied as file mounted  # noqa: E501

        :param secrets_as_mount: The secrets_as_mount of this Environment.  # noqa: E501
        :type: str
        """

        self._secrets_as_mount = secrets_as_mount

    @property
    def secrets_as_env(self):
        """Gets the secrets_as_env of this Environment.  # noqa: E501

        A json object of secrets applied as environment  # noqa: E501

        :return: The secrets_as_env of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._secrets_as_env

    @secrets_as_env.setter
    def secrets_as_env(self, secrets_as_env):
        """Sets the secrets_as_env of this Environment.

        A json object of secrets applied as environment  # noqa: E501

        :param secrets_as_env: The secrets_as_env of this Environment.  # noqa: E501
        :type: str
        """

        self._secrets_as_env = secrets_as_env

    @property
    def application_services(self):
        """Gets the application_services of this Environment.  # noqa: E501

        The services used by the application for this environment. Note that in order to add a service to the environment, this environment must be added to the list of assignments for that service in the ApplicationService collection for the organisation.   # noqa: E501

        :return: The application_services of this Environment.  # noqa: E501
        :rtype: list[ApplicationService]
        """
        return self._application_services

    @application_services.setter
    def application_services(self, application_services):
        """Sets the application_services of this Environment.

        The services used by the application for this environment. Note that in order to add a service to the environment, this environment must be added to the list of assignments for that service in the ApplicationService collection for the organisation.   # noqa: E501

        :param application_services: The application_services of this Environment.  # noqa: E501
        :type: list[ApplicationService]
        """

        self._application_services = application_services

    @property
    def serverless_image(self):
        """Gets the serverless_image of this Environment.  # noqa: E501

        serverless image path  # noqa: E501

        :return: The serverless_image of this Environment.  # noqa: E501
        :rtype: str
        """
        return self._serverless_image

    @serverless_image.setter
    def serverless_image(self, serverless_image):
        """Sets the serverless_image of this Environment.

        serverless image path  # noqa: E501

        :param serverless_image: The serverless_image of this Environment.  # noqa: E501
        :type: str
        """

        self._serverless_image = serverless_image

    @property
    def status(self):
        """Gets the status of this Environment.  # noqa: E501


        :return: The status of this Environment.  # noqa: E501
        :rtype: EnvironmentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Environment.


        :param status: The status of this Environment.  # noqa: E501
        :type: EnvironmentStatus
        """

        self._status = status

    @property
    def updated(self):
        """Gets the updated of this Environment.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this Environment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Environment.

        Update time  # noqa: E501

        :param updated: The updated of this Environment.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Environment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Environment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Log(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'log': 'str',
        'stream': 'str',
        'timestamp': 'str',
        'app': 'str',
        'org_id': 'str',
        'sub_org_id': 'str',
        'env': 'str'
    }

    attribute_map = {
        'log': 'log',
        'stream': 'stream',
        'timestamp': 'timestamp',
        'app': 'app',
        'org_id': 'org_id',
        'sub_org_id': 'sub_org_id',
        'env': 'env'
    }

    def __init__(self, log=None, stream=None, timestamp=None, app=None, org_id=None, sub_org_id=None, env=None, local_vars_configuration=None):  # noqa: E501
        """Log - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._log = None
        self._stream = None
        self._timestamp = None
        self._app = None
        self._org_id = None
        self._sub_org_id = None
        self._env = None
        self.discriminator = None

        if log is not None:
            self.log = log
        if stream is not None:
            self.stream = stream
        if timestamp is not None:
            self.timestamp = timestamp
        if app is not None:
            self.app = app
        if org_id is not None:
            self.org_id = org_id
        if sub_org_id is not None:
            self.sub_org_id = sub_org_id
        if env is not None:
            self.env = env

    @property
    def log(self):
        """Gets the log of this Log.  # noqa: E501

        log  # noqa: E501

        :return: The log of this Log.  # noqa: E501
        :rtype: str
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this Log.

        log  # noqa: E501

        :param log: The log of this Log.  # noqa: E501
        :type: str
        """

        self._log = log

    @property
    def stream(self):
        """Gets the stream of this Log.  # noqa: E501

        log stream  # noqa: E501

        :return: The stream of this Log.  # noqa: E501
        :rtype: str
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        """Sets the stream of this Log.

        log stream  # noqa: E501

        :param stream: The stream of this Log.  # noqa: E501
        :type: str
        """

        self._stream = stream

    @property
    def timestamp(self):
        """Gets the timestamp of this Log.  # noqa: E501

        timestamp of log  # noqa: E501

        :return: The timestamp of this Log.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Log.

        timestamp of log  # noqa: E501

        :param timestamp: The timestamp of this Log.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def app(self):
        """Gets the app of this Log.  # noqa: E501

        name of application associated with log  # noqa: E501

        :return: The app of this Log.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this Log.

        name of application associated with log  # noqa: E501

        :param app: The app of this Log.  # noqa: E501
        :type: str
        """

        self._app = app

    @property
    def org_id(self):
        """Gets the org_id of this Log.  # noqa: E501

        unique shortuuid for the  organisation  # noqa: E501

        :return: The org_id of this Log.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this Log.

        unique shortuuid for the  organisation  # noqa: E501

        :param org_id: The org_id of this Log.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def sub_org_id(self):
        """Gets the sub_org_id of this Log.  # noqa: E501

        unique shortuuid for the sub-organisation  # noqa: E501

        :return: The sub_org_id of this Log.  # noqa: E501
        :rtype: str
        """
        return self._sub_org_id

    @sub_org_id.setter
    def sub_org_id(self, sub_org_id):
        """Sets the sub_org_id of this Log.

        unique shortuuid for the sub-organisation  # noqa: E501

        :param sub_org_id: The sub_org_id of this Log.  # noqa: E501
        :type: str
        """

        self._sub_org_id = sub_org_id

    @property
    def env(self):
        """Gets the env of this Log.  # noqa: E501

        environment that app is running in  # noqa: E501

        :return: The env of this Log.  # noqa: E501
        :rtype: str
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this Log.

        environment that app is running in  # noqa: E501

        :param env: The env of this Log.  # noqa: E501
        :type: str
        """

        self._env = env

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Log):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Log):
            return True

        return self.to_dict() != other.to_dict()



import csv
import sys

from . import context


def update_if_not_none(obj: dict, new_values: dict):
    for k, v in new_values.items():
        if v is not None:
            obj[k] = v


def pop_item_if_none(obj: dict):
    if not obj:
        return

    keys_to_pop = []
    for k, v in obj.items():
        if v is None:
            keys_to_pop.append(k)
    for k in keys_to_pop:
        obj.pop(k)


def build_updated_model(klass, model, new_values):
    model_dict = model.to_dict()
    update_if_not_none(model_dict, new_values)
    return klass(**model_dict)


def get_org_from_input_or_ctx(ctx, org_id=None, **kwargs):
    if org_id is None:
        token = context.get_token(ctx)
        org_id = context.get_org_id(ctx, token)

    # Treat an empty-string org id like None so that we can query all if necessary
    if org_id == "":
        org_id = None

    return org_id


def get_user_id_from_input_or_ctx(ctx, user_id=None, **kwargs):
    if user_id is None:
        token = context.get_token(ctx)
        user_id = context.get_user_id(ctx, token)

    # Treat an empty-string like None so that we can query all if necessary
    if user_id == "":
        user_id = None

    return user_id


def parse_csv_input(input_filename, parser):
    input_file = sys.stdin
    if input_filename != "-":
        input_file = open(input_filename, "r")

    results = list()
    with input_file:
        csv_input = csv.DictReader(input_file, delimiter=",", quotechar='"')

        for result_dict in csv_input:
            result = parser(result_dict)
            if result:
                results.append(result)

    return results



import json
import urllib.parse

import requests
import agilicus

from . import context, response, token_parser


def _create_token(ctx, user_id, duration, aud, hosts=[], roles={}, org_id=None):
    token = context.get_token(ctx)

    headers = {}
    headers["Authorization"] = "Bearer {}".format(token)
    headers["Content-type"] = "application/json"

    data = {}
    data["sub"] = user_id
    data["time_validity"] = {"duration": duration}
    data["audiences"] = aud
    if hosts:
        data["hosts"] = hosts
    if org_id:
        data["org"] = org_id
    if roles:
        data["roles"] = roles

    response = requests.post(
        context.get_api(ctx) + "/v1/tokens",
        headers=headers,
        data=json.dumps(data),
        verify=context.get_cacert(ctx),
    )
    return response


def get_introspect(ctx, raw_token, exclude_roles, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)
    options = agilicus.TokenIntrospectOptions(exclude_roles=exclude_roles)
    token_obj = agilicus.TokenIntrospect(token=raw_token, introspect_options=options)
    resp = apiclient.tokens_api.create_introspect_token(token_obj, **kwargs)
    return resp


def get_token(ctx, user_id, org_id, duration, hosts):
    token = context.get_token(ctx)

    if not org_id:
        tok = token_parser.Token(token)
        if tok.hasRole("urn:api:agilicus:traffic-tokens", "owner"):
            org_id = tok.getOrg()

    hosts = json.loads(hosts)
    aud = [
        "urn:api:agilicus:gateway",
        "urn:api:agilicus:users",
        "urn:api:agilicus:applications",
    ]
    return _create_token(
        ctx, user_id, duration, aud=aud, hosts=hosts, org_id=org_id
    ).text


def create_token(ctx, user_id, roles, duration, audiences, org_id):
    result = _create_token(
        ctx, user_id, duration, aud=audiences, roles=roles, org_id=org_id
    )
    if result.status_code != 200:
        print("Unable to retrieve token: %i" % result.status_code)
        print(result.text)
        return None
    return result.text


def query_tokens(
    ctx,
    limit=None,
    expired_from=None,
    expired_to=None,
    issued_from=None,
    issued_to=None,
    org_id=None,
    jti=None,
    sub=None,
):
    token = context.get_token(ctx)

    headers = {}
    headers["Authorization"] = "Bearer {}".format(token)

    params = {}
    if limit:
        params["limit"] = limit
    if expired_from:
        params["exp_from"] = expired_from
    if expired_to:
        params["exp_to"] = expired_to
    if issued_from:
        params["iat_from"] = issued_from
    if issued_to:
        params["iat_to"] = issued_to
    if jti:
        params["jti"] = jti
    if sub:
        params["sub"] = sub
    if org_id:
        params["org"] = org_id
    else:
        org_id = context.get_org_id(ctx, token)
        if org_id:
            params["org"] = org_id

    query = urllib.parse.urlencode(params)
    uri = "/v1/tokens?{}".format(query)
    resp = requests.get(
        context.get_api(ctx) + uri,
        headers=headers,
        verify=context.get_cacert(ctx),
    )
    response.validate(resp)
    return resp.text



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class EnvironmentConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'app_id': 'str',
        'environment_name': 'str',
        'maintenance_org_id': 'str',
        'config_type': 'str',
        'mount_domain': 'str',
        'mount_username': 'str',
        'mount_password': 'str',
        'mount_hostname': 'str',
        'mount_share': 'str',
        'mount_src_path': 'str',
        'mount_path': 'str',
        'file_store_uri': 'str',
        'env_config_vars': 'list[EnvironmentConfigVar]'
    }

    attribute_map = {
        'id': 'id',
        'app_id': 'app_id',
        'environment_name': 'environment_name',
        'maintenance_org_id': 'maintenance_org_id',
        'config_type': 'config_type',
        'mount_domain': 'mount_domain',
        'mount_username': 'mount_username',
        'mount_password': 'mount_password',
        'mount_hostname': 'mount_hostname',
        'mount_share': 'mount_share',
        'mount_src_path': 'mount_src_path',
        'mount_path': 'mount_path',
        'file_store_uri': 'file_store_uri',
        'env_config_vars': 'env_config_vars'
    }

    def __init__(self, id=None, app_id=None, environment_name=None, maintenance_org_id=None, config_type=None, mount_domain=None, mount_username=None, mount_password=None, mount_hostname=None, mount_share=None, mount_src_path=None, mount_path=None, file_store_uri=None, env_config_vars=None, local_vars_configuration=None):  # noqa: E501
        """EnvironmentConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._app_id = None
        self._environment_name = None
        self._maintenance_org_id = None
        self._config_type = None
        self._mount_domain = None
        self._mount_username = None
        self._mount_password = None
        self._mount_hostname = None
        self._mount_share = None
        self._mount_src_path = None
        self._mount_path = None
        self._file_store_uri = None
        self._env_config_vars = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if app_id is not None:
            self.app_id = app_id
        if environment_name is not None:
            self.environment_name = environment_name
        self.maintenance_org_id = maintenance_org_id
        self.config_type = config_type
        if mount_domain is not None:
            self.mount_domain = mount_domain
        if mount_username is not None:
            self.mount_username = mount_username
        if mount_password is not None:
            self.mount_password = mount_password
        if mount_hostname is not None:
            self.mount_hostname = mount_hostname
        if mount_share is not None:
            self.mount_share = mount_share
        if mount_src_path is not None:
            self.mount_src_path = mount_src_path
        if mount_path is not None:
            self.mount_path = mount_path
        if file_store_uri is not None:
            self.file_store_uri = file_store_uri
        if env_config_vars is not None:
            self.env_config_vars = env_config_vars

    @property
    def id(self):
        """Gets the id of this EnvironmentConfig.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EnvironmentConfig.

        Unique identifier  # noqa: E501

        :param id: The id of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def app_id(self):
        """Gets the app_id of this EnvironmentConfig.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The app_id of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this EnvironmentConfig.

        Unique identifier  # noqa: E501

        :param app_id: The app_id of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def environment_name(self):
        """Gets the environment_name of this EnvironmentConfig.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The environment_name of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._environment_name

    @environment_name.setter
    def environment_name(self, environment_name):
        """Sets the environment_name of this EnvironmentConfig.

        Unique identifier  # noqa: E501

        :param environment_name: The environment_name of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._environment_name = environment_name

    @property
    def maintenance_org_id(self):
        """Gets the maintenance_org_id of this EnvironmentConfig.  # noqa: E501

        The Organisation which is responsibile for maintaining this Environment.   # noqa: E501

        :return: The maintenance_org_id of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_org_id

    @maintenance_org_id.setter
    def maintenance_org_id(self, maintenance_org_id):
        """Sets the maintenance_org_id of this EnvironmentConfig.

        The Organisation which is responsibile for maintaining this Environment.   # noqa: E501

        :param maintenance_org_id: The maintenance_org_id of this EnvironmentConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and maintenance_org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `maintenance_org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                maintenance_org_id is not None and len(maintenance_org_id) > 40):
            raise ValueError("Invalid value for `maintenance_org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                maintenance_org_id is not None and len(maintenance_org_id) < 1):
            raise ValueError("Invalid value for `maintenance_org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._maintenance_org_id = maintenance_org_id

    @property
    def config_type(self):
        """Gets the config_type of this EnvironmentConfig.  # noqa: E501

        configuration type  # noqa: E501

        :return: The config_type of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """Sets the config_type of this EnvironmentConfig.

        configuration type  # noqa: E501

        :param config_type: The config_type of this EnvironmentConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and config_type is None:  # noqa: E501
            raise ValueError("Invalid value for `config_type`, must not be `None`")  # noqa: E501
        allowed_values = ["configmap_mount", "configmap_env", "secret_mount", "secret_env", "file_mount", "mount_smb", "mount_gcs", "mount_tmpdir"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and config_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `config_type` ({0}), must be one of {1}"  # noqa: E501
                .format(config_type, allowed_values)
            )

        self._config_type = config_type

    @property
    def mount_domain(self):
        """Gets the mount_domain of this EnvironmentConfig.  # noqa: E501

        mount user domain  # noqa: E501

        :return: The mount_domain of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_domain

    @mount_domain.setter
    def mount_domain(self, mount_domain):
        """Sets the mount_domain of this EnvironmentConfig.

        mount user domain  # noqa: E501

        :param mount_domain: The mount_domain of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_domain = mount_domain

    @property
    def mount_username(self):
        """Gets the mount_username of this EnvironmentConfig.  # noqa: E501

        mount username  # noqa: E501

        :return: The mount_username of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_username

    @mount_username.setter
    def mount_username(self, mount_username):
        """Sets the mount_username of this EnvironmentConfig.

        mount username  # noqa: E501

        :param mount_username: The mount_username of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_username = mount_username

    @property
    def mount_password(self):
        """Gets the mount_password of this EnvironmentConfig.  # noqa: E501

        mount password  # noqa: E501

        :return: The mount_password of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_password

    @mount_password.setter
    def mount_password(self, mount_password):
        """Sets the mount_password of this EnvironmentConfig.

        mount password  # noqa: E501

        :param mount_password: The mount_password of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_password = mount_password

    @property
    def mount_hostname(self):
        """Gets the mount_hostname of this EnvironmentConfig.  # noqa: E501

        mount hostname  # noqa: E501

        :return: The mount_hostname of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_hostname

    @mount_hostname.setter
    def mount_hostname(self, mount_hostname):
        """Sets the mount_hostname of this EnvironmentConfig.

        mount hostname  # noqa: E501

        :param mount_hostname: The mount_hostname of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_hostname = mount_hostname

    @property
    def mount_share(self):
        """Gets the mount_share of this EnvironmentConfig.  # noqa: E501

        mount share  # noqa: E501

        :return: The mount_share of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_share

    @mount_share.setter
    def mount_share(self, mount_share):
        """Sets the mount_share of this EnvironmentConfig.

        mount share  # noqa: E501

        :param mount_share: The mount_share of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_share = mount_share

    @property
    def mount_src_path(self):
        """Gets the mount_src_path of this EnvironmentConfig.  # noqa: E501

        source mount path  # noqa: E501

        :return: The mount_src_path of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_src_path

    @mount_src_path.setter
    def mount_src_path(self, mount_src_path):
        """Sets the mount_src_path of this EnvironmentConfig.

        source mount path  # noqa: E501

        :param mount_src_path: The mount_src_path of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_src_path = mount_src_path

    @property
    def mount_path(self):
        """Gets the mount_path of this EnvironmentConfig.  # noqa: E501

        destination mount path  # noqa: E501

        :return: The mount_path of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._mount_path

    @mount_path.setter
    def mount_path(self, mount_path):
        """Sets the mount_path of this EnvironmentConfig.

        destination mount path  # noqa: E501

        :param mount_path: The mount_path of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._mount_path = mount_path

    @property
    def file_store_uri(self):
        """Gets the file_store_uri of this EnvironmentConfig.  # noqa: E501

        files API URI where configuration is located  # noqa: E501

        :return: The file_store_uri of this EnvironmentConfig.  # noqa: E501
        :rtype: str
        """
        return self._file_store_uri

    @file_store_uri.setter
    def file_store_uri(self, file_store_uri):
        """Sets the file_store_uri of this EnvironmentConfig.

        files API URI where configuration is located  # noqa: E501

        :param file_store_uri: The file_store_uri of this EnvironmentConfig.  # noqa: E501
        :type: str
        """

        self._file_store_uri = file_store_uri

    @property
    def env_config_vars(self):
        """Gets the env_config_vars of this EnvironmentConfig.  # noqa: E501

        It stores an array of env_config_var objects(key & value pairs) in API. It provides environment variables to build configmaps and secrets directly.   # noqa: E501

        :return: The env_config_vars of this EnvironmentConfig.  # noqa: E501
        :rtype: list[EnvironmentConfigVar]
        """
        return self._env_config_vars

    @env_config_vars.setter
    def env_config_vars(self, env_config_vars):
        """Sets the env_config_vars of this EnvironmentConfig.

        It stores an array of env_config_var objects(key & value pairs) in API. It provides environment variables to build configmaps and secrets directly.   # noqa: E501

        :param env_config_vars: The env_config_vars of this EnvironmentConfig.  # noqa: E501
        :type: list[EnvironmentConfigVar]
        """

        self._env_config_vars = env_config_vars

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnvironmentConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EnvironmentConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_auth_audits_response import ListAuthAuditsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListAuthAuditsResponse(unittest.TestCase):
    """ListAuthAuditsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListAuthAuditsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_auth_audits_response.ListAuthAuditsResponse()  # noqa: E501
        if include_optional :
            return ListAuthAuditsResponse(
                auth_audits = [
                    agilicus_api.models.auth_audits.AuthAudits(
                        user_id = 'jjkkGmwB9oTJWDjIglTU', 
                        upstream_user_id = 'asvl2-1a1s-asdlk-3sl1', 
                        org_id = '2jkMGmwB9o7JW3jIglNZ', 
                        org_name = '2jkMGmwB9o7JW3jIglNZ', 
                        time = '2020-05-16T19:11:18Z', 
                        event = 'Timeout', 
                        source_ip = '192.0.2.1', 
                        token_id = 'XMYdZy7yAiudMDxQqgDwkY', 
                        trace_id = '00b893c9ec7c0089c3da65e7c9e2263a', 
                        session = '00b893c9ec7c0089c3da65e7c9e2263a', 
                        issuer = 'https://auth.cloud.egov.city', 
                        client_id = 'my-client-id-ABCD', 
                        application_name = 'app-1', 
                        login_org_id = 'Io7MGmwB9o7JW3jIg23B', 
                        login_org_name = 'Io7MGmwB9o7JW3jIg23B', 
                        upstream_idp = 'google', 
                        stage = 'Login', 
                        user_agent = 'Mozilla/5.0 (X11; Linux x86_64) Chrome/83.0.4103.97 Safari/537.36', )
                    ], 
                limit = 56
            )
        else :
            return ListAuthAuditsResponse(
                limit = 56,
        )

    def testListAuthAuditsResponse(self):
        """Test ListAuthAuditsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ApplicationAssignment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'org_id': 'str',
        'environment_name': 'str',
        'application_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'org_id': 'org_id',
        'environment_name': 'environment_name',
        'application_name': 'application_name'
    }

    def __init__(self, id=None, org_id=None, environment_name=None, application_name=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationAssignment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._org_id = None
        self._environment_name = None
        self._application_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.org_id = org_id
        self.environment_name = environment_name
        if application_name is not None:
            self.application_name = application_name

    @property
    def id(self):
        """Gets the id of this ApplicationAssignment.  # noqa: E501

        The unique identifier for the assignment.  # noqa: E501

        :return: The id of this ApplicationAssignment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApplicationAssignment.

        The unique identifier for the assignment.  # noqa: E501

        :param id: The id of this ApplicationAssignment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def org_id(self):
        """Gets the org_id of this ApplicationAssignment.  # noqa: E501

        The unique identifier for the organisation which is being given access to the application environment.   # noqa: E501

        :return: The org_id of this ApplicationAssignment.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this ApplicationAssignment.

        The unique identifier for the organisation which is being given access to the application environment.   # noqa: E501

        :param org_id: The org_id of this ApplicationAssignment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def environment_name(self):
        """Gets the environment_name of this ApplicationAssignment.  # noqa: E501

        The name of the environment of the application for which to give access.   # noqa: E501

        :return: The environment_name of this ApplicationAssignment.  # noqa: E501
        :rtype: str
        """
        return self._environment_name

    @environment_name.setter
    def environment_name(self, environment_name):
        """Sets the environment_name of this ApplicationAssignment.

        The name of the environment of the application for which to give access.   # noqa: E501

        :param environment_name: The environment_name of this ApplicationAssignment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and environment_name is None:  # noqa: E501
            raise ValueError("Invalid value for `environment_name`, must not be `None`")  # noqa: E501

        self._environment_name = environment_name

    @property
    def application_name(self):
        """Gets the application_name of this ApplicationAssignment.  # noqa: E501

        The display name for the application for which to give access. Provided on get for convenience. Do not set the field for modifying operations as it will be ignored.   # noqa: E501

        :return: The application_name of this ApplicationAssignment.  # noqa: E501
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """Sets the application_name of this ApplicationAssignment.

        The display name for the application for which to give access. Provided on get for convenience. Do not set the field for modifying operations as it will be ignored.   # noqa: E501

        :param application_name: The application_name of this ApplicationAssignment.  # noqa: E501
        :type: str
        """

        self._application_name = application_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationAssignment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationAssignment):
            return True

        return self.to_dict() != other.to_dict()



import datetime
import operator

from dataclasses import dataclass
from typing import Callable

from prettytable import PrettyTable


def format_date(date_input):
    return date_input.strftime("%Y-%m-%d %H:%M:%S %z (%Z)")


def date_else_identity(input_obj):
    if isinstance(input_obj, datetime.datetime):
        return format_date(input_obj)
    return input_obj


@dataclass
class OutputColumn:
    in_name: str
    out_name: str
    format_fn: Callable = date_else_identity
    getter: Callable = None


def column(name):
    return OutputColumn(in_name=name, out_name=name)


def mapped_column(in_name, out_name):
    return OutputColumn(in_name=in_name, out_name=out_name)


def subtable(in_name, columns, out_name=None, subobject_name=None):
    if not out_name:
        out_name = in_name

    def format_fn(records):
        return format_table(records, columns)

    def getter(record, base_getter):
        subobject = base_getter(subobject_name)(record)
        return base_getter(in_name)(subobject)

    col_getter = None
    if subobject_name:
        col_getter = getter

    return OutputColumn(
        in_name=in_name, out_name=out_name, format_fn=format_fn, getter=col_getter
    )


def subobject_column(in_name, out_name, subobject_name):
    if not out_name:
        out_name = in_name

    def getter(record, base_getter):
        subobject = base_getter(subobject_name)(record)
        return base_getter(in_name)(subobject)

    return OutputColumn(in_name=in_name, out_name=out_name, getter=getter)


def metadata_column(in_name, out_name=None):
    return subobject_column(in_name, out_name, "metadata")


def spec_column(in_name, out_name=None):
    return subobject_column(in_name, out_name, "spec")


def status_column(in_name, out_name=None):
    return subobject_column(in_name, out_name, "status")


def format_table(records, columns, getter=operator.attrgetter):
    table = PrettyTable([column.out_name for column in columns])
    if not records:
        return table

    for record in records:
        row = []
        for column in columns:
            in_value = None
            if column.getter:
                in_value = column.getter(record, getter)
            else:
                in_value = getter(column.in_name)(record)

            out_value = "---"
            if in_value is not None:
                out_value = column.format_fn(in_value)
            row.append(out_value)

        table.add_row(row)
    table.align = "l"
    return table



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.issuer_client import IssuerClient  # noqa: E501
from agilicus_api.rest import ApiException

class TestIssuerClient(unittest.TestCase):
    """IssuerClient unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test IssuerClient
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.issuer_client.IssuerClient()  # noqa: E501
        if include_optional :
            return IssuerClient(
                id = '123', 
                issuer_id = '123', 
                name = '0', 
                secret = '0', 
                application = '0', 
                org_id = '0', 
                restricted_organisations = ["org-1","org-2"], 
                saml_metadata_file = '0', 
                organisation_scope = 'here_only', 
                redirects = [
                    '0'
                    ], 
                mfa_challenge = 'user_preference', 
                attributes = [
                    agilicus_api.models.authentication_attribute.AuthenticationAttribute(
                        attribute_name = 'emailAddress', 
                        internal_attribute_path = 'user.email', )
                    ]
            )
        else :
            return IssuerClient(
                name = '0',
        )

    def testIssuerClient(self):
        """Test IssuerClient"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class PolicyRuleSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'action': 'str',
        'priority': 'int',
        'org_id': 'str',
        'conditions': 'list[PolicyCondition]'
    }

    attribute_map = {
        'name': 'name',
        'action': 'action',
        'priority': 'priority',
        'org_id': 'org_id',
        'conditions': 'conditions'
    }

    def __init__(self, name=None, action=None, priority=1, org_id=None, conditions=None, local_vars_configuration=None):  # noqa: E501
        """PolicyRuleSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._action = None
        self._priority = None
        self._org_id = None
        self._conditions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.action = action
        if priority is not None:
            self.priority = priority
        if org_id is not None:
            self.org_id = org_id
        self.conditions = conditions

    @property
    def name(self):
        """Gets the name of this PolicyRuleSpec.  # noqa: E501

        A descriptive name of the policy rule to help administrators identify each rule. A name should describe the business logic the rule is satisfying.  # noqa: E501

        :return: The name of this PolicyRuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicyRuleSpec.

        A descriptive name of the policy rule to help administrators identify each rule. A name should describe the business logic the rule is satisfying.  # noqa: E501

        :param name: The name of this PolicyRuleSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def action(self):
        """Gets the action of this PolicyRuleSpec.  # noqa: E501

        The action to take if the conditions are evaluated to true. Actions are case sensitive.  # noqa: E501

        :return: The action of this PolicyRuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this PolicyRuleSpec.

        The action to take if the conditions are evaluated to true. Actions are case sensitive.  # noqa: E501

        :param action: The action of this PolicyRuleSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action is None:  # noqa: E501
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                action is not None and len(action) > 100):
            raise ValueError("Invalid value for `action`, length must be less than or equal to `100`")  # noqa: E501

        self._action = action

    @property
    def priority(self):
        """Gets the priority of this PolicyRuleSpec.  # noqa: E501

        This field is deprecated. The priority of this rule relative to other rules. Rules of a higher priority will be evaluated first and if the condition evaluates to true the action will be taken. 1 is the highest priority.  # noqa: E501

        :return: The priority of this PolicyRuleSpec.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this PolicyRuleSpec.

        This field is deprecated. The priority of this rule relative to other rules. Rules of a higher priority will be evaluated first and if the condition evaluates to true the action will be taken. 1 is the highest priority.  # noqa: E501

        :param priority: The priority of this PolicyRuleSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                priority is not None and priority < 1):  # noqa: E501
            raise ValueError("Invalid value for `priority`, must be a value greater than or equal to `1`")  # noqa: E501

        self._priority = priority

    @property
    def org_id(self):
        """Gets the org_id of this PolicyRuleSpec.  # noqa: E501

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :return: The org_id of this PolicyRuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this PolicyRuleSpec.

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :param org_id: The org_id of this PolicyRuleSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def conditions(self):
        """Gets the conditions of this PolicyRuleSpec.  # noqa: E501

        An array mapping a condition type to a condition.  # noqa: E501

        :return: The conditions of this PolicyRuleSpec.  # noqa: E501
        :rtype: list[PolicyCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this PolicyRuleSpec.

        An array mapping a condition type to a condition.  # noqa: E501

        :param conditions: The conditions of this PolicyRuleSpec.  # noqa: E501
        :type: list[PolicyCondition]
        """
        if self.local_vars_configuration.client_side_validation and conditions is None:  # noqa: E501
            raise ValueError("Invalid value for `conditions`, must not be `None`")  # noqa: E501

        self._conditions = conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyRuleSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicyRuleSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ChallengeStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'state': 'str',
        'public_challenge': 'str'
    }

    attribute_map = {
        'state': 'state',
        'public_challenge': 'public_challenge'
    }

    def __init__(self, state=None, public_challenge=None, local_vars_configuration=None):  # noqa: E501
        """ChallengeStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._state = None
        self._public_challenge = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if public_challenge is not None:
            self.public_challenge = public_challenge

    @property
    def state(self):
        """Gets the state of this ChallengeStatus.  # noqa: E501

        The current state of the challenge. The challenge may be in the following states:   - pending: waiting to issue the challenge.   - challenge_failed: the system failed to issue the challenge. This could be because there is     no mechanism to do so, communication with the device failed, and so on.   - issued: the challenge has been issued. The system is waiting for a response.   - challenge_passed: the user passed the challenge, typically by accepting a notification.   - challenge_declined: the user declined to accept the challenge. The challenge is no longer valid.   - timed_out: the challenge has timed out. The user can no longer use an answer to it to prove their     possession of a second factor.   # noqa: E501

        :return: The state of this ChallengeStatus.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ChallengeStatus.

        The current state of the challenge. The challenge may be in the following states:   - pending: waiting to issue the challenge.   - challenge_failed: the system failed to issue the challenge. This could be because there is     no mechanism to do so, communication with the device failed, and so on.   - issued: the challenge has been issued. The system is waiting for a response.   - challenge_passed: the user passed the challenge, typically by accepting a notification.   - challenge_declined: the user declined to accept the challenge. The challenge is no longer valid.   - timed_out: the challenge has timed out. The user can no longer use an answer to it to prove their     possession of a second factor.   # noqa: E501

        :param state: The state of this ChallengeStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "issued", "challenge_failed", "challenge_passed", "challenge_declined", "timed_out"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def public_challenge(self):
        """Gets the public_challenge of this ChallengeStatus.  # noqa: E501

        An opaque string used as the public challenge. Currently this is only used when the challenge type is webauthn.  # noqa: E501

        :return: The public_challenge of this ChallengeStatus.  # noqa: E501
        :rtype: str
        """
        return self._public_challenge

    @public_challenge.setter
    def public_challenge(self, public_challenge):
        """Sets the public_challenge of this ChallengeStatus.

        An opaque string used as the public challenge. Currently this is only used when the challenge type is webauthn.  # noqa: E501

        :param public_challenge: The public_challenge of this ChallengeStatus.  # noqa: E501
        :type: str
        """

        self._public_challenge = public_challenge

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChallengeStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChallengeStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class MFAChallengeMethodSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'priority': 'int',
        'challenge_type': 'str',
        'endpoint': 'str',
        'nickname': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'priority': 'priority',
        'challenge_type': 'challenge_type',
        'endpoint': 'endpoint',
        'nickname': 'nickname',
        'enabled': 'enabled'
    }

    def __init__(self, priority=None, challenge_type=None, endpoint=None, nickname=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """MFAChallengeMethodSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._priority = None
        self._challenge_type = None
        self._endpoint = None
        self._nickname = None
        self._enabled = None
        self.discriminator = None

        self.priority = priority
        self.challenge_type = challenge_type
        self.endpoint = endpoint
        if nickname is not None:
            self.nickname = nickname
        if enabled is not None:
            self.enabled = enabled

    @property
    def priority(self):
        """Gets the priority of this MFAChallengeMethodSpec.  # noqa: E501

        The priority of this challenge method. Priority is how the user specifies which challenge method to be notified with if that method is supported.  A priority of 1 is the highest priority and indicates that the user prefers this challenge method.  # noqa: E501

        :return: The priority of this MFAChallengeMethodSpec.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this MFAChallengeMethodSpec.

        The priority of this challenge method. Priority is how the user specifies which challenge method to be notified with if that method is supported.  A priority of 1 is the highest priority and indicates that the user prefers this challenge method.  # noqa: E501

        :param priority: The priority of this MFAChallengeMethodSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and priority is None:  # noqa: E501
            raise ValueError("Invalid value for `priority`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                priority is not None and priority < 1):  # noqa: E501
            raise ValueError("Invalid value for `priority`, must be a value greater than or equal to `1`")  # noqa: E501

        self._priority = priority

    @property
    def challenge_type(self):
        """Gets the challenge_type of this MFAChallengeMethodSpec.  # noqa: E501

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :return: The challenge_type of this MFAChallengeMethodSpec.  # noqa: E501
        :rtype: str
        """
        return self._challenge_type

    @challenge_type.setter
    def challenge_type(self, challenge_type):
        """Sets the challenge_type of this MFAChallengeMethodSpec.

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :param challenge_type: The challenge_type of this MFAChallengeMethodSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and challenge_type is None:  # noqa: E501
            raise ValueError("Invalid value for `challenge_type`, must not be `None`")  # noqa: E501

        self._challenge_type = challenge_type

    @property
    def endpoint(self):
        """Gets the endpoint of this MFAChallengeMethodSpec.  # noqa: E501

        The specific device to issue the challenge to. The meaning of this field may change depending on the challenge type specified.  # noqa: E501

        :return: The endpoint of this MFAChallengeMethodSpec.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this MFAChallengeMethodSpec.

        The specific device to issue the challenge to. The meaning of this field may change depending on the challenge type specified.  # noqa: E501

        :param endpoint: The endpoint of this MFAChallengeMethodSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and endpoint is None:  # noqa: E501
            raise ValueError("Invalid value for `endpoint`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                endpoint is not None and len(endpoint) > 511):
            raise ValueError("Invalid value for `endpoint`, length must be less than or equal to `511`")  # noqa: E501

        self._endpoint = endpoint

    @property
    def nickname(self):
        """Gets the nickname of this MFAChallengeMethodSpec.  # noqa: E501

        A descriptive name the user can set to differentiate their challenge methods.  # noqa: E501

        :return: The nickname of this MFAChallengeMethodSpec.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this MFAChallengeMethodSpec.

        A descriptive name the user can set to differentiate their challenge methods.  # noqa: E501

        :param nickname: The nickname of this MFAChallengeMethodSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                nickname is not None and len(nickname) > 100):
            raise ValueError("Invalid value for `nickname`, length must be less than or equal to `100`")  # noqa: E501

        self._nickname = nickname

    @property
    def enabled(self):
        """Gets the enabled of this MFAChallengeMethodSpec.  # noqa: E501

        The state of the challenge method. A value of true indicates that the method is active. A value of false indicates that the method is disabled. When a method is disabled it will not be used as an authentication factor when the user logs in.   # noqa: E501

        :return: The enabled of this MFAChallengeMethodSpec.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this MFAChallengeMethodSpec.

        The state of the challenge method. A value of true indicates that the method is active. A value of false indicates that the method is disabled. When a method is disabled it will not be used as an authentication factor when the user logs in.   # noqa: E501

        :param enabled: The enabled of this MFAChallengeMethodSpec.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MFAChallengeMethodSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MFAChallengeMethodSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class WebAuthNEnrollmentSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'relying_party_id': 'str',
        'attestation_format': 'str',
        'attestation_conveyance': 'str',
        'user_verification': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'relying_party_id': 'relying_party_id',
        'attestation_format': 'attestation_format',
        'attestation_conveyance': 'attestation_conveyance',
        'user_verification': 'user_verification'
    }

    def __init__(self, user_id=None, relying_party_id=None, attestation_format=None, attestation_conveyance=None, user_verification='discouraged', local_vars_configuration=None):  # noqa: E501
        """WebAuthNEnrollmentSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._relying_party_id = None
        self._attestation_format = None
        self._attestation_conveyance = None
        self._user_verification = None
        self.discriminator = None

        self.user_id = user_id
        self.relying_party_id = relying_party_id
        if attestation_format is not None:
            self.attestation_format = attestation_format
        if attestation_conveyance is not None:
            self.attestation_conveyance = attestation_conveyance
        if user_verification is not None:
            self.user_verification = user_verification

    @property
    def user_id(self):
        """Gets the user_id of this WebAuthNEnrollmentSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The user_id of this WebAuthNEnrollmentSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebAuthNEnrollmentSpec.

        Unique identifier  # noqa: E501

        :param user_id: The user_id of this WebAuthNEnrollmentSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def relying_party_id(self):
        """Gets the relying_party_id of this WebAuthNEnrollmentSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The relying_party_id of this WebAuthNEnrollmentSpec.  # noqa: E501
        :rtype: str
        """
        return self._relying_party_id

    @relying_party_id.setter
    def relying_party_id(self, relying_party_id):
        """Sets the relying_party_id of this WebAuthNEnrollmentSpec.

        Unique identifier  # noqa: E501

        :param relying_party_id: The relying_party_id of this WebAuthNEnrollmentSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and relying_party_id is None:  # noqa: E501
            raise ValueError("Invalid value for `relying_party_id`, must not be `None`")  # noqa: E501

        self._relying_party_id = relying_party_id

    @property
    def attestation_format(self):
        """Gets the attestation_format of this WebAuthNEnrollmentSpec.  # noqa: E501

        The format of the attestation statement for this challenge.  # noqa: E501

        :return: The attestation_format of this WebAuthNEnrollmentSpec.  # noqa: E501
        :rtype: str
        """
        return self._attestation_format

    @attestation_format.setter
    def attestation_format(self, attestation_format):
        """Sets the attestation_format of this WebAuthNEnrollmentSpec.

        The format of the attestation statement for this challenge.  # noqa: E501

        :param attestation_format: The attestation_format of this WebAuthNEnrollmentSpec.  # noqa: E501
        :type: str
        """

        self._attestation_format = attestation_format

    @property
    def attestation_conveyance(self):
        """Gets the attestation_conveyance of this WebAuthNEnrollmentSpec.  # noqa: E501

        The relying parties attestation conveyance preference.  # noqa: E501

        :return: The attestation_conveyance of this WebAuthNEnrollmentSpec.  # noqa: E501
        :rtype: str
        """
        return self._attestation_conveyance

    @attestation_conveyance.setter
    def attestation_conveyance(self, attestation_conveyance):
        """Sets the attestation_conveyance of this WebAuthNEnrollmentSpec.

        The relying parties attestation conveyance preference.  # noqa: E501

        :param attestation_conveyance: The attestation_conveyance of this WebAuthNEnrollmentSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["direct", "indirect", "none"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and attestation_conveyance not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `attestation_conveyance` ({0}), must be one of {1}"  # noqa: E501
                .format(attestation_conveyance, allowed_values)
            )

        self._attestation_conveyance = attestation_conveyance

    @property
    def user_verification(self):
        """Gets the user_verification of this WebAuthNEnrollmentSpec.  # noqa: E501

        A WebAuthn Relying Party may require user verification for some of its operations but not for others, and may use this type to express its needs.   # noqa: E501

        :return: The user_verification of this WebAuthNEnrollmentSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_verification

    @user_verification.setter
    def user_verification(self, user_verification):
        """Sets the user_verification of this WebAuthNEnrollmentSpec.

        A WebAuthn Relying Party may require user verification for some of its operations but not for others, and may use this type to express its needs.   # noqa: E501

        :param user_verification: The user_verification of this WebAuthNEnrollmentSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["required", "preferred", "discouraged"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and user_verification not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `user_verification` ({0}), must be one of {1}"  # noqa: E501
                .format(user_verification, allowed_values)
            )

        self._user_verification = user_verification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebAuthNEnrollmentSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebAuthNEnrollmentSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class GroupsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_group_member(self, group_id, add_group_member_request, **kwargs):  # noqa: E501
        """Add a group member  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_group_member(group_id, add_group_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param AddGroupMemberRequest add_group_member_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_group_member_with_http_info(group_id, add_group_member_request, **kwargs)  # noqa: E501

    def add_group_member_with_http_info(self, group_id, add_group_member_request, **kwargs):  # noqa: E501
        """Add a group member  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_group_member_with_http_info(group_id, add_group_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param AddGroupMemberRequest add_group_member_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(User, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'add_group_member_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_group_member" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `add_group_member`")  # noqa: E501
        # verify the required parameter 'add_group_member_request' is set
        if self.api_client.client_side_validation and ('add_group_member_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_group_member_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_group_member_request` when calling `add_group_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_group_member_request' in local_var_params:
            body_params = local_var_params['add_group_member_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}/members', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_group(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Group group: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_group_with_http_info(group, **kwargs)  # noqa: E501

    def create_group_with_http_info(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group_with_http_info(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Group group: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Group, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group' is set
        if self.api_client.client_side_validation and ('group' not in local_var_params or  # noqa: E501
                                                        local_var_params['group'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group` when calling `create_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in local_var_params:
            body_params = local_var_params['group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_group(self, group_id, **kwargs):  # noqa: E501
        """Delete a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def delete_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Delete a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `delete_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_group_member(self, group_id, member_id, **kwargs):  # noqa: E501
        """Remove a group member  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_member(group_id, member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str member_id: member_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_group_member_with_http_info(group_id, member_id, **kwargs)  # noqa: E501

    def delete_group_member_with_http_info(self, group_id, member_id, **kwargs):  # noqa: E501
        """Remove a group member  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_member_with_http_info(group_id, member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str member_id: member_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'member_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group_member" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `delete_group_member`")  # noqa: E501
        # verify the required parameter 'member_id' is set
        if self.api_client.client_side_validation and ('member_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['member_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `member_id` when calling `delete_group_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501
        if 'member_id' in local_var_params:
            path_params['member_id'] = local_var_params['member_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}/members/{member_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group(self, group_id, **kwargs):  # noqa: E501
        """Get a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def get_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Group, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `get_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_groups(self, **kwargs):  # noqa: E501
        """Get all groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str org_id: Organisation Unique identifier
        :param str type: group type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListGroupsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_groups_with_http_info(**kwargs)  # noqa: E501

    def list_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get all groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str org_id: Organisation Unique identifier
        :param str type: group type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListGroupsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['org_id', 'type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListGroupsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_group(self, group_id, **kwargs):  # noqa: E501
        """update a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param Group group:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def replace_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """update a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param Group group:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `replace_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in local_var_params:
            body_params = local_var_params['group']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.09.29
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.files_api import FilesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.files_api.FilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_file(self):
        """Test case for add_file

        upload a file  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Delete a File  # noqa: E501
        """
        pass

    def test_get_download(self):
        """Test case for get_download

        Download File  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Get File metadata  # noqa: E501
        """
        pass

    def test_list_files(self):
        """Test case for list_files

        Query Files  # noqa: E501
        """
        pass

    def test_replace_file(self):
        """Test case for replace_file

        Update a file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
